@@ -230,23 +230,25 @@ impl<'a, I: Input> Lexer<'a, I> {
             }
         }
 
-        if let Some(ref comments) = self.comments {
-            let s = self.input.slice(slice_start, end);
-            let cmt = Comment {
-                kind: CommentKind::Line,
-                span: Span::new(start, end, SyntaxContext::empty()),
-                text: s.into(),
-            };
+        if !self.ctx.dont_store_comments {
+            if let Some(ref comments) = self.comments {
+                let s = self.input.slice(slice_start, end);
+                let cmt = Comment {
+                    kind: CommentKind::Line,
+                    span: Span::new(start, end, SyntaxContext::empty()),
+                    text: s.into(),
+                };
 
-            if start >= *self.last_comment_pos.borrow() {
-                *self.last_comment_pos.borrow_mut() = end;
+                if start >= *self.last_comment_pos.borrow() {
+                    *self.last_comment_pos.borrow_mut() = end;
 
-                if is_for_next {
-                    if let Some(buf) = &self.leading_comments_buffer {
-                        buf.borrow_mut().push(cmt);
+                    if is_for_next {
+                        if let Some(buf) = &self.leading_comments_buffer {
+                            buf.borrow_mut().push(cmt);
+                        }
+                    } else {
+                        comments.add_trailing(self.state.prev_hi, cmt);
                     }
-                } else {
-                    comments.add_trailing(self.state.prev_hi, cmt);
                 }
             }
         }
@@ -281,28 +283,32 @@ impl<'a, I: Input> Lexer<'a, I> {
                 self.bump(); // '/'
 
                 let end = self.cur_pos();
-                if let Some(ref comments) = self.comments {
-                    let src = self.input.slice(slice_start, end);
-                    let s = &src[..src.len() - 2];
-                    let cmt = Comment {
-                        kind: CommentKind::Block,
-                        span: Span::new(start, end, SyntaxContext::empty()),
-                        text: s.into(),
-                    };
 
-                    let _ = self.input.peek();
-                    if start >= *self.last_comment_pos.borrow() {
-                        *self.last_comment_pos.borrow_mut() = end;
+                if !self.ctx.dont_store_comments {
+                    if let Some(ref comments) = self.comments {
+                        let src = self.input.slice(slice_start, end);
+                        let s = &src[..src.len() - 2];
+                        let cmt = Comment {
+                            kind: CommentKind::Block,
+                            span: Span::new(start, end, SyntaxContext::empty()),
+                            text: s.into(),
+                        };
 
-                        if is_for_next {
-                            if let Some(buf) = &self.leading_comments_buffer {
-                                buf.borrow_mut().push(cmt);
+                        let _ = self.input.peek();
+                        if start >= *self.last_comment_pos.borrow() {
+                            *self.last_comment_pos.borrow_mut() = end;
+
+                            if is_for_next {
+                                if let Some(buf) = &self.leading_comments_buffer {
+                                    buf.borrow_mut().push(cmt);
+                                }
+                            } else {
+                                comments.add_trailing(self.state.prev_hi, cmt);
                             }
-                        } else {
-                            comments.add_trailing(self.state.prev_hi, cmt);
                         }
                     }
                 }
+
                 return Ok(());
             }
             if c.is_line_terminator() {
